.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

.. image:: https://travis-ci.com/collective/cs.zestreleaser.eggbuilder.svg?branch=master
    :target: https://travis-ci.com/collective/cs.zestreleaser.eggbuilder

.. image:: https://coveralls.io/repos/github/collective/cs.zestreleaser.eggbuilder/badge.svg?branch=master
    :target: https://coveralls.io/github/collective/cs.zestreleaser.eggbuilder?branch=master
    :alt: Coveralls

.. image:: https://img.shields.io/pypi/v/cs.zestreleaser.eggbuilder.svg
    :target: https://pypi.python.org/pypi/cs.zestreleaser.eggbuilder/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/cs.zestreleaser.eggbuilder.svg
    :target: https://pypi.python.org/pypi/cs.zestreleaser.eggbuilder
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/cs.zestreleaser.eggbuilder.svg?style=plastic
    :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/cs.zestreleaser.eggbuilder.svg
    :target: https://pypi.python.org/pypi/cs.zestreleaser.eggbuilder/
    :alt: License


==========================
cs.zestreleaser.eggbuilder
==========================

Create egg files if the user wants

We have a client that uses some old deployment scripts that needs \*.egg files to complete
the deployment.

So using this zest.releaser plugin we can build egg files automatically for the package
we are relasing.


License
-------

The project is licensed under the GPLv2.
